@@ -66,6 +66,7 @@ MODEL_INFO_NAMES = {
     "CL-BL": "",  # Send on the 0x1C table lamp
     "ZG-BL-IR": "IR",
     "IR": "IR",
+    "IR_MINI": "IR Mini",
     "ZG-BL-EH7W": "7w",
     "ZG-BL-IH9WL": "9w RF",
     "ZG-BL-IH9W": "9w RF",
@@ -389,7 +390,7 @@ HARDWARE = [
         remote_rf=False,  # verified
         remote_24g=False,
         remote_24g_controls=False,
-        auto_on=False,
+        auto_on=True,
         dimmable_effects=False,
     ),
     LEDENETHardware(
@@ -650,6 +651,7 @@ MODELS = [
         model_num=0x04,
         # AK001-ZJ100 == v3.09, v3.15 (Illume)
         # AK001-ZJ200 == v5.20
+        # AK001-ZJ2104 == v6.20 (Dals)
         # There are a limited set of these devices that are the mini version but most are UFOs
         models=[
             "HF-LPB100",
@@ -658,10 +660,14 @@ MODELS = [
             "HF-LPB100-ZJ002",
             "AK001-ZJ100",
             "AK001-ZJ200",
+            "AK001-ZJ2104",
         ],
-        description="UFO Controller RGBW",  # AKA ZJ-WFUF-170F
+        description="Controller RGB&W",  # AKA ZJ-WFUF-170F
         always_writes_white_and_colors=True,  # Formerly rgbwprotocol
-        protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE)],
+        protocols=[
+            MinVersionProtocol(6, PROTOCOL_LEDENET_8BYTE_AUTO_ON),
+            MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE),
+        ],
         mode_to_color_mode={},
         color_modes={COLOR_MODE_RGBW},  # Formerly rgbwcapable
         channel_map={},
@@ -670,7 +676,7 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x06,
-        # "AK001-ZJ2104" == v1 has RF remote support
+        # "AK001-ZJ2104" == v1.11 has RF remote support
         # "AK001-ZJ2145" == v2.03, v2.06, v2.09 has IR remote support but not always pinned out
         # "AK001-ZJ2147" == v3.31 has 2.4ghz remote support
         models=[
@@ -684,6 +690,7 @@ MODELS = [
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
         protocols=[
             MinVersionProtocol(2, PROTOCOL_LEDENET_8BYTE_DIMMABLE_EFFECTS),
+            MinVersionProtocol(1, PROTOCOL_LEDENET_8BYTE_AUTO_ON),
             MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE),
         ],
         mode_to_color_mode=GENERIC_RGBW_MAP,
@@ -920,7 +927,7 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x25,
-        # 'AK001-ZJ200' == v2 - some devices have RF remote support (the mini ones)
+        # 'AK001-ZJ200' == v2.08 - some devices have RF remote support (the mini ones)
         models=["HF-LPB100-ZJ200", "AK001-ZJ200"],
         description="Controller RGB/WW/CW",
         always_writes_white_and_colors=True,  # Formerly rgbwprotocol
@@ -933,20 +940,20 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x33,
-        # 'AK001-ZJ100' == v3.03 - WIFI370 version
-        # 'AK001-ZJ210' == v6.37 - Seen on the outdoor string lights from Lytworx
+        # 'AK001-ZJ100' == v3.03 WIFI370 version, v3.11 IR_mini
+        # 'AK001-ZJ210' == v6.37 - Seen on the outdoor string lights from Lytworx -- May support auto on?
         # 'AK001-ZJ2104' == v7.07 - Seen on usb fairy lights - supports turning on by effect/levels set
         # 'AK001-ZJ2134' == v8.02 - seen on the water proof controllers for outdoor garden light
         # 'AK001-ZJ2101' == v8.61, 8.62 (44 key) - no dimmable effects confirmed, confirmed auto on
-        # "AK001-ZJ2145" == v9 # no rf support!
-        # "AK001-ZJ2145" == v9.27, 9.30, 9.33 # w/IR
-        # "AK001-ZJ2146" == v10.48 # 2.4ghz support
+        # "AK001-ZJ2145" == v9.25, v9.27, 9.30, 9.33 # w/IR
+        # "AK001-ZJ2146" == v10.48 # 2.4ghz support, some have IR
         # "AK001-ZJ2148" == v10.63 # 2.4ghz support, confirmed to be able to change 2.4G remote settings
         models=[
             "AK001-ZJ100",
             "AK001-ZJ210",
             "AK001-ZJ2104",
             "AK001-ZJ2101",
+            "AK001-ZJ2134",
             "AK001-ZJ2145",
             "AK001-ZJ2146",
             "AK001-ZJ2148",
@@ -955,7 +962,7 @@ MODELS = [
         always_writes_white_and_colors=True,  # Formerly rgbwprotocol
         protocols=[
             MinVersionProtocol(9, PROTOCOL_LEDENET_8BYTE_DIMMABLE_EFFECTS),
-            MinVersionProtocol(7, PROTOCOL_LEDENET_8BYTE_AUTO_ON),
+            MinVersionProtocol(6, PROTOCOL_LEDENET_8BYTE_AUTO_ON),
             MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE),
         ],
         mode_to_color_mode=GENERIC_RGB_MAP,
@@ -966,9 +973,10 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x35,
-        # 'AK001-ZJ2101' is v7.63 and 'AK001-ZJ2104' is v7
-        # 'AK001-ZJ2145' is v8
-        # 'AK001-ZJ2146' is v9, 40w flood light, newer smart bulbs (with RF remote control support)
+        # 'AK001-ZJ2101' is v7.63
+        # 'AK001-ZJ2104' is v7.07
+        # 'AK001-ZJ2145' is v8.47, v8.56 - seen on 7w bulbs
+        # 'AK001-ZJ2146' is v9.62, 40w flood light, newer smart bulbs (with RF remote control support)
         # 'AK001-ZJ2147' is v9.7 (with RF remote control support)
         # 'AK001-ZJ21410' is v9.91 seen on the Bunpeon smart floor light ASIN:B09MN65324
         models=[
@@ -1011,13 +1019,13 @@ MODELS = [
     LEDENETModel(
         model_num=0x44,
         # v8 - AK001-ZJ200 aka old flux
-        # v9 - AK001-ZJ210
+        # v9.34 - AK001-ZJ210
         # v10.49 - AK001-ZJ2101
         models=["AK001-ZJ200", "AK001-ZJ210", "AK001-ZJ2101"],
         description="Bulb RGBW",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
         protocols=[
-            MinVersionProtocol(10, PROTOCOL_LEDENET_8BYTE_AUTO_ON),
+            MinVersionProtocol(9, PROTOCOL_LEDENET_8BYTE_AUTO_ON),
             MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE),
         ],
         mode_to_color_mode={},
@@ -1173,7 +1181,7 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0xA2,
-        # 'AK001-ZJ2104' likely supports turning on by effect/levels set
+        # 'AK001-ZJ2104' = v2.33 supports turning on by effect/levels set
         models=["AK001-ZJ2104"],
         description="Addressable v2",
         always_writes_white_and_colors=False,
@@ -1322,7 +1330,7 @@ def get_model_description(model_num: int, model_info: Optional[str]) -> str:
 def format_model_description(description: str, model_info: Optional[str]) -> str:
     """Format the description for a model."""
     if model_info:
-        extra = MODEL_INFO_NAMES.get(model_info)
+        extra = MODEL_INFO_NAMES.get(model_info.upper())
         if extra:
             return f"{description} {extra}"
     return description
