@@ -2189,22 +2189,19 @@ class ProtocolLEDENETAddressableChristmas(ProtocolLEDENETAddressableBase):
         self, pattern: int, speed: int, brightness: int
     ) -> bytearray:
         """The bytes to send for a preset pattern.
-
-        OUTER_MESSAGE_WRAPPER = [0xB0, 0xB1, 0xB2, 0xB3, 0x00, 0x01, 0x01]
-
-        b0 b1 b2 b3 00 01 01 2b 00 07 a3 01 10 00 00 00 b4 62
-
-          inner = a3 01 10 00 00 00 b4
+        0xB0 0xB1 0xB2 0xB3 0x00 0x01 0x01 0x2A 0x00 0x04 0x38 0x01 0x10 0x00 0x3F (15)
+        0xB0 0xB1 0xB2 0xB3 0x00 0x01 0x01 0x2B 0x00 0x04 0x38 0x02 0x10 0x00 0x41 (15)
+        0xB0 0xB1 0xB2 0xB3 0x00 0x01 0x01 0x2C 0x00 0x04 0x38 0x03 0x10 0x00 0x43 (15)
+        0xB0 0xB1 0xB2 0xB3 0x00 0x01 0x01 0x2D 0x00 0x04 0x38 0x04 0x10 0x00 0x45 (15)
+        0xB0 0xB1 0xB2 0xB3 0x00 0x01 0x01 0x2E 0x00 0x04 0x38 0x05 0x10 0x00 0x47 (15)
+        0xB0 0xB1 0xB2 0xB3 0x00 0x01 0x01 0x2F 0x00 0x04 0x38 0x06 0x10 0x00 0x49 (15)
         """
         return self.construct_wrapped_message(
             bytearray(
                 [
-                    0xA3,
+                    0x38,
                     pattern,
                     utils.speedToDelay(speed),
-                    0x00,
-                    0x00,
-                    0x00,
                 ]
             )
         )
@@ -2318,7 +2315,7 @@ class ProtocolLEDENETAddressableChristmas(ProtocolLEDENETAddressableBase):
         sent_zones = len(rgb_list)
         if sent_zones > points:
             raise ValueError(f"Device supports a maximum of {points} zones")
-        msg = bytearray([0xA0, 0x00, 0x60])
+        msg = bytearray([0xA0, 0x00, 0x06])
         zone_size = points // sent_zones
         remaining = points
         for rgb in rgb_list:
